@@ -7,10 +7,12 @@ import sys
 import tempfile
 import warnings
 from functools import lru_cache
+from html.parser import HTMLParser
 from pathlib import Path
 from typing import Dict, List, Optional, Set, Tuple, Union
+from urllib import parse
 
-from pipenv import environments
+from pipenv import environments, resolver
 from pipenv.exceptions import RequirementError, ResolutionFailure
 from pipenv.patched.pip._internal.cache import WheelCache
 from pipenv.patched.pip._internal.commands.install import InstallCommand
@@ -29,11 +31,9 @@ from pipenv.patched.pip._internal.utils.temp_dir import global_tempdir_manager
 from pipenv.patched.pip._vendor import pkg_resources, rich
 from pipenv.project import Project
 from pipenv.vendor import click
-from pipenv.vendor.requirementslib import Requirement
-from pipenv.vendor.requirementslib.models.requirements import Line
+from pipenv.vendor.requirementslib.fileutils import create_tracked_tempdir, open_file
+from pipenv.vendor.requirementslib.models.requirements import Line, Requirement
 from pipenv.vendor.requirementslib.models.utils import DIRECT_URL_RE
-from pipenv.vendor.vistir import open_file
-from pipenv.vendor.vistir.path import create_tracked_tempdir
 
 try:
     # this is only in Python3.8 and later
@@ -121,7 +121,21 @@ class HashCacheMixin:
         with open_file(link.url, self.session) as fp:
             for chunk in iter(lambda: fp.read(8096), b""):
                 h.update(chunk)
-        return ":".join([h.name, h.hexdigest()])
+        return f"{h.name}:{h.hexdigest()}"
+
+
+class PackageIndexHTMLParser(HTMLParser):
+    def __init__(self):
+        super().__init__()
+        self.urls = []
+
+    def handle_starttag(self, tag, attrs):
+        # If tag is an anchor
+        if tag == "a":
+            # find href attribute
+            for attr in attrs:
+                if attr[0] == "href":
+                    self.urls.append(attr[1])
 
 
 class Resolver:
@@ -158,13 +172,13 @@ class Resolver:
         self._parsed_constraints = None
         self._resolver = None
         self._finder = None
-        self._ignore_compatibility_finder = None
         self._session = None
         self._constraint_file = None
         self._pip_options = None
         self._pip_command = None
         self._retry_attempts = 0
         self._hash_cache = None
+        self._sessions = {}
 
     def __repr__(self):
         return (
@@ -257,7 +271,6 @@ class Resolver:
         markers_lookup: Dict[str, str] = None,
         project: Optional[Project] = None,
     ) -> Tuple[Requirement, Dict[str, str], Dict[str, str]]:
-
         if index_lookup is None:
             index_lookup = {}
         if markers_lookup is None:
@@ -268,13 +281,13 @@ class Resolver:
             project = Project()
         index, extra_index, trust_host, remainder = parse_indexes(line)
         line = " ".join(remainder)
-        req: Requirement = None
         try:
             req = Requirement.from_line(line)
         except ValueError:
             direct_url = DIRECT_URL_RE.match(line)
             if direct_url:
-                line = "{}#egg={}".format(line, direct_url.groupdict()["name"])
+                name = direct_url.groupdict()["name"]
+                line = f"{name}@ {line}"
                 try:
                     req = Requirement.from_line(line)
                 except ValueError:
@@ -332,8 +345,10 @@ class Resolver:
                 name = req.normalized_name
             except TypeError:
                 raise RequirementError(req=req)
-            setup_info = req.req.setup_info
-            setup_info.get_info()
+            if parsed_line.setup_info:
+                setup_info = parsed_line.setup_info
+            else:
+                setup_info = req.req.parse_setup_info()
             locked_deps[pep423_name(name)] = entry
             requirements = []
             # Allow users to toggle resolution off for non-editable VCS packages
@@ -347,7 +362,16 @@ class Resolver:
                     and is_installable_dir(parsed_line.path)
                 )
             ):
+                setup_info.run_pyproject()
+                setup_info.run_setup()
                 requirements = [v for v in getattr(setup_info, "requires", {}).values()]
+                if req.extras:
+                    for extra in req.extras:
+                        requirements.extend(
+                            v
+                            for v in getattr(setup_info, "extras", {}).get(extra, [])
+                            if v not in requirements
+                        )
             for r in requirements:
                 if getattr(r, "url", None) and not getattr(r, "editable", False):
                     if r is not None:
@@ -376,9 +400,7 @@ class Resolver:
                 if req.specifiers:
                     locked_deps[name]["version"] = req.specifiers
                 elif parsed_line.setup_info and parsed_line.setup_info.version:
-                    locked_deps[name]["version"] = "=={}".format(
-                        parsed_line.setup_info.version
-                    )
+                    locked_deps[name]["version"] = f"=={parsed_line.setup_info.version}"
             # if not req.is_vcs:
             locked_deps.update({name: entry})
         else:
@@ -402,8 +424,8 @@ class Resolver:
                     )
                     hashes = resolver.collect_hashes(ireq) if resolver else []
                     new_req = Requirement.from_ireq(ireq)
-                    new_req = new_req.add_hashes(hashes)
-                    new_req = new_req.merge_markers(req.markers)
+                    new_req.add_hashes(hashes)
+                    new_req.merge_markers(req.markers)
                     name, entry = new_req.pipfile_entry
                     locked_deps[pep423_name(name)] = translate_markers(entry)
                     click.echo(
@@ -435,7 +457,6 @@ class Resolver:
         pre: bool = False,
         category: str = None,
     ) -> "Resolver":
-
         if not req_dir:
             req_dir = create_tracked_tempdir(suffix="-requirements", prefix="pipenv-")
         if index_lookup is None:
@@ -572,26 +593,6 @@ class Resolver:
         self._finder._link_collector.search_scope.index_lookup = index_lookup
         return self._finder
 
-    @property
-    def ignore_compatibility_finder(self):
-        if self._ignore_compatibility_finder is None:
-            ignore_compatibility_finder = get_package_finder(
-                install_cmd=self.pip_command,
-                options=self.pip_options,
-                session=self.session,
-            )
-            # It would be nice if `shims.get_package_finder` took an
-            # `ignore_compatibility` parameter, but that's some vendorered code
-            # we'd rather avoid touching.
-            index_lookup = self.prepare_index_lookup()
-            ignore_compatibility_finder._ignore_compatibility = True
-            self._ignore_compatibility_finder = ignore_compatibility_finder
-            self._ignore_compatibility_finder._link_collector.index_lookup = index_lookup
-            self._ignore_compatibility_finder._link_collector.search_scope.index_lookup = (
-                index_lookup
-            )
-        return self._ignore_compatibility_finder
-
     @property
     def parsed_constraints(self):
         pip_options = self.pip_options
@@ -652,10 +653,12 @@ class Resolver:
     def get_resolver(self, clear=False):
         from pipenv.patched.pip._internal.utils.temp_dir import TempDirectory
 
-        with global_tempdir_manager(), get_build_tracker() as build_tracker, TempDirectory() as directory:
+        with global_tempdir_manager(), get_build_tracker() as build_tracker, TempDirectory(
+            globally_managed=True
+        ) as directory:
             pip_options = self.pip_options
             finder = self.finder
-            wheel_cache = WheelCache(pip_options.cache_dir, pip_options.format_control)
+            wheel_cache = WheelCache(pip_options.cache_dir)
             preparer = self.pip_command.make_requirement_preparer(
                 temp_build_dir=directory,
                 options=pip_options,
@@ -705,7 +708,6 @@ class Resolver:
                     requires_python = candidate.link.requires_python
                     if requires_python:
                         try:
-
                             marker = marker_from_specifier(requires_python)
                             self.markers[result.name] = marker
                             result.markers = marker
@@ -732,9 +734,19 @@ class Resolver:
             cleaned_checksums.add(checksum)
         return cleaned_checksums
 
-    def _get_hashes_from_pypi(self, ireq):
+    def _get_requests_session_for_source(self, source):
+        if self._sessions.get(source["name"]):
+            session = self._sessions[source["name"]]
+        else:
+            session = _get_requests_session(
+                self.project.s.PIPENV_MAX_RETRIES, source.get("verify_ssl", True)
+            )
+            self._sessions[source["name"]] = session
+        return session
+
+    def _get_hashes_from_pypi(self, ireq, source):
         pkg_url = f"https://pypi.org/pypi/{ireq.name}/json"
-        session = _get_requests_session(self.project.s.PIPENV_MAX_RETRIES)
+        session = self._get_requests_session_for_source(source)
         try:
             collected_hashes = set()
             # Grab the hashes from the new warehouse API.
@@ -762,6 +774,42 @@ class Resolver:
                 )
             return None
 
+    def _get_hashes_from_remote_index_urls(self, ireq, source):
+        pkg_url = f"{source['url']}/{ireq.name}/"
+        session = self._get_requests_session_for_source(source)
+        try:
+            collected_hashes = set()
+            # Grab the hashes from the new warehouse API.
+            response = session.get(pkg_url, timeout=10)
+            # Create an instance of the parser
+            parser = PackageIndexHTMLParser()
+            # Feed the HTML to the parser
+            parser.feed(response.text)
+            # Extract hrefs
+            hrefs = parser.urls
+
+            version = ""
+            if ireq.specifier:
+                spec = next(iter(s for s in ireq.specifier), None)
+                if spec:
+                    version = spec.version
+            for package_url in hrefs:
+                if version in package_url:
+                    url_params = parse.urlparse(package_url).fragment
+                    params_dict = parse.parse_qs(url_params)
+                    if params_dict.get(FAVORITE_HASH):
+                        collected_hashes.add(params_dict[FAVORITE_HASH][0])
+            return self.prepend_hash_types(collected_hashes, FAVORITE_HASH)
+        except (ValueError, KeyError, ConnectionError):
+            if self.project.s.is_verbose():
+                click.echo(
+                    "{}: Error generating hash for {}".format(
+                        click.style("Warning", bold=True, fg="red"), ireq.name
+                    ),
+                    err=True,
+                )
+            return None
+
     def collect_hashes(self, ireq):
         link = ireq.link  # Handle VCS and file links first
         if link and (link.is_vcs or (link.is_file and link.is_existing_dir())):
@@ -777,12 +825,18 @@ class Resolver:
             sources = list(
                 filter(lambda s: s.get("name") == self.index_lookup[ireq.name], sources)
             )
-        if any(is_pypi_url(source["url"]) for source in sources):
-            hashes = self._get_hashes_from_pypi(ireq)
-            if hashes:
-                return hashes
+        source = sources[0] if len(sources) else None
+        if source:
+            if is_pypi_url(source["url"]):
+                hashes = self._get_hashes_from_pypi(ireq, source)
+                if hashes:
+                    return hashes
+            else:
+                hashes = self._get_hashes_from_remote_index_urls(ireq, source)
+                if hashes:
+                    return hashes
 
-        applicable_candidates = self.ignore_compatibility_finder.find_best_candidate(
+        applicable_candidates = self.finder.find_best_candidate(
             ireq.name, ireq.specifier
         ).iter_applicable()
         applicable_candidates = list(applicable_candidates)
@@ -811,7 +865,7 @@ class Resolver:
         ref = None
         if req.is_vcs:
             ref = req.commit_hash
-        ireq = req.as_ireq()
+        ireq = req.ireq
         entry = value.copy()
         entry["name"] = req.name
         if entry.get("editable", False) and entry.get("version"):
@@ -825,8 +879,6 @@ class Resolver:
         return req.name, entry
 
     def clean_results(self):
-        from pipenv.vendor.requirementslib.models.requirements import Requirement
-
         reqs = [(Requirement.from_ireq(ireq), ireq) for ireq in self.resolved_tree]
         results = {}
         for req, ireq in reqs:
@@ -835,7 +887,7 @@ class Resolver:
             elif req.normalized_name in self.skipped.keys():
                 continue
             collected_hashes = self.hashes.get(ireq, set())
-            req = req.add_hashes(collected_hashes)
+            req.add_hashes(collected_hashes)
             if collected_hashes:
                 collected_hashes = sorted(collected_hashes)
             name, entry = format_requirement_for_lockfile(
@@ -879,11 +931,8 @@ def actually_resolve_deps(
     clear,
     pre,
     category,
-    req_dir=None,
+    req_dir,
 ):
-    if not req_dir:
-        req_dir = create_tracked_tempdir(suffix="-requirements", prefix="pipenv-")
-
     with warnings.catch_warnings(record=True) as warning_list:
         resolver = Resolver.create(
             deps,
@@ -912,7 +961,6 @@ def actually_resolve_deps(
 
 
 def resolve(cmd, st, project):
-    from pipenv._compat import decode_output
     from pipenv.cmdparse import Script
     from pipenv.vendor.click import echo
 
@@ -920,22 +968,21 @@ def resolve(cmd, st, project):
     is_verbose = project.s.is_verbose()
     err = ""
     for line in iter(c.stderr.readline, ""):
-        line = decode_output(line)
         if not line.rstrip():
             continue
         err += line
         if is_verbose:
-            st.update(line.rstrip())
+            st.console.print(line.rstrip())
 
     c.wait()
     returncode = c.poll()
     out = c.stdout.read()
     if returncode != 0:
-        st.update(environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!"))
+        st.console.print(environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!"))
         echo(out.strip(), err=True)
         if not is_verbose:
             echo(err, err=True)
-        sys.exit(returncode)
+        raise RuntimeError("Failed to lock Pipfile.lock!")
     if is_verbose:
         echo(out.strip(), err=True)
     return subprocess.CompletedProcess(c.args, returncode, out, err)
@@ -952,7 +999,6 @@ def venv_resolve_deps(
     pypi_mirror=None,
     pipfile=None,
     lockfile=None,
-    keep_outdated=False,
 ):
     """
     Resolve dependencies for a pipenv project, acts as a portal to the target environment.
@@ -973,13 +1019,10 @@ def venv_resolve_deps(
     :param pipfile: A Pipfile section to operate on, defaults to None
     :type pipfile: Optional[Dict[str, Union[str, Dict[str, bool, List[str]]]]]
     :param Dict[str, Any] lockfile: A project lockfile to mutate, defaults to None
-    :param bool keep_outdated: Whether to retain outdated dependencies and resolve with them in mind, defaults to False
     :raises RuntimeError: Raised on resolution failure
-    :return: Nothing
-    :rtype: None
+    :return: The lock data
+    :rtype: dict
     """
-    from pipenv import resolver
-
     lockfile_section = get_lockfile_section_using_pipfile_category(category)
 
     if not deps:
@@ -991,79 +1034,106 @@ def venv_resolve_deps(
 
     if not pipfile:
         pipfile = getattr(project, category, {})
-    if not lockfile:
-        lockfile = project._lockfile(categories=[category])
+    if lockfile is None:
+        lockfile = project.lockfile(categories=[category])
     req_dir = create_tracked_tempdir(prefix="pipenv", suffix="requirements")
-    cmd = [
-        which("python", allow_global=allow_global),
-        Path(resolver.__file__.rstrip("co")).as_posix(),
-    ]
-    if pre:
-        cmd.append("--pre")
-    if clear:
-        cmd.append("--clear")
-    if allow_global:
-        cmd.append("--system")
-    if category:
-        cmd.append("--category")
-        cmd.append(category)
-    target_file = tempfile.NamedTemporaryFile(
-        prefix="resolver", suffix=".json", delete=False
-    )
-    target_file.close()
-    cmd.extend(["--write", make_posix(target_file.name)])
+    results = []
     with temp_environ():
         os.environ.update({k: str(val) for k, val in os.environ.items()})
         if pypi_mirror:
             os.environ["PIPENV_PYPI_MIRROR"] = str(pypi_mirror)
-        os.environ["PIPENV_VERBOSITY"] = str(project.s.PIPENV_VERBOSITY)
-        os.environ["PIPENV_REQ_DIR"] = req_dir
         os.environ["PIP_NO_INPUT"] = "1"
         pipenv_site_dir = get_pipenv_sitedir()
         if pipenv_site_dir is not None:
             os.environ["PIPENV_SITE_DIR"] = pipenv_site_dir
         else:
             os.environ.pop("PIPENV_SITE_DIR", None)
-        if keep_outdated:
-            os.environ["PIPENV_KEEP_OUTDATED"] = "1"
         with console.status("Locking...", spinner=project.s.PIPENV_SPINNER) as st:
             # This conversion is somewhat slow on local and file-type requirements since
             # we now download those requirements / make temporary folders to perform
             # dependency resolution on them, so we are including this step inside the
             # spinner context manager for the UX improvement
-            st.update("Building requirements...")
+            st.console.print("Building requirements...")
             deps = convert_deps_to_pip(deps, project, include_index=True)
             constraints = set(deps)
-            with tempfile.NamedTemporaryFile(
-                mode="w+", prefix="pipenv", suffix="constraints.txt", delete=False
-            ) as constraints_file:
-                constraints_file.write(str("\n".join(constraints)))
-            cmd.append("--constraints-file")
-            cmd.append(constraints_file.name)
-            st.update("Resolving dependencies...")
-            c = resolve(cmd, st, project=project)
-            if c.returncode == 0:
-                st.update(environments.PIPENV_SPINNER_OK_TEXT.format("Success!"))
-                if not project.s.is_verbose() and c.stderr.strip():
-                    click.echo(click.style(f"Warning: {c.stderr.strip()}"), err=True)
-            else:
-                st.update(environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!"))
-                click.echo(f"Output: {c.stdout.strip()}", err=True)
-                click.echo(f"Error: {c.stderr.strip()}", err=True)
-    try:
-        with open(target_file.name) as fh:
-            results = json.load(fh)
-    except (IndexError, json.JSONDecodeError):
-        click.echo(c.stdout.strip(), err=True)
-        click.echo(c.stderr.strip(), err=True)
-        if os.path.exists(target_file.name):
-            os.unlink(target_file.name)
-        raise RuntimeError("There was a problem with locking.")
-    if os.path.exists(target_file.name):
-        os.unlink(target_file.name)
+            st.console.print("Resolving dependencies...")
+            # Useful for debugging and hitting breakpoints in the resolver
+            if project.s.PIPENV_RESOLVER_PARENT_PYTHON:
+                try:
+                    results = resolver.resolve_packages(
+                        pre,
+                        clear,
+                        project.s.is_verbose(),
+                        system=allow_global,
+                        write=False,
+                        requirements_dir=req_dir,
+                        packages=deps,
+                        category=category,
+                        constraints=constraints,
+                    )
+                    if results:
+                        st.console.print(
+                            environments.PIPENV_SPINNER_OK_TEXT.format("Success!")
+                        )
+                except Exception:
+                    st.console.print(
+                        environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!")
+                    )
+                    raise
+            else:  # Default/Production behavior is to use project python's resolver
+                cmd = [
+                    which("python", allow_global=allow_global),
+                    Path(resolver.__file__.rstrip("co")).as_posix(),
+                ]
+                if pre:
+                    cmd.append("--pre")
+                if clear:
+                    cmd.append("--clear")
+                if allow_global:
+                    cmd.append("--system")
+                if category:
+                    cmd.append("--category")
+                    cmd.append(category)
+                target_file = tempfile.NamedTemporaryFile(
+                    prefix="resolver", suffix=".json", delete=False
+                )
+                target_file.close()
+                cmd.extend(["--write", make_posix(target_file.name)])
+
+                with tempfile.NamedTemporaryFile(
+                    mode="w+", prefix="pipenv", suffix="constraints.txt", delete=False
+                ) as constraints_file:
+                    constraints_file.write(str("\n".join(constraints)))
+                cmd.append("--constraints-file")
+                cmd.append(constraints_file.name)
+                st.console.print("Resolving dependencies...")
+                c = resolve(cmd, st, project=project)
+                if c.returncode == 0:
+                    try:
+                        with open(target_file.name) as fh:
+                            results = json.load(fh)
+                    except (IndexError, json.JSONDecodeError):
+                        click.echo(c.stdout.strip(), err=True)
+                        click.echo(c.stderr.strip(), err=True)
+                        if os.path.exists(target_file.name):
+                            os.unlink(target_file.name)
+                        raise RuntimeError("There was a problem with locking.")
+                    if os.path.exists(target_file.name):
+                        os.unlink(target_file.name)
+                    st.console.print(
+                        environments.PIPENV_SPINNER_OK_TEXT.format("Success!")
+                    )
+                    if not project.s.is_verbose() and c.stderr.strip():
+                        click.echo(click.style(f"Warning: {c.stderr.strip()}"), err=True)
+                else:
+                    st.console.print(
+                        environments.PIPENV_SPINNER_FAIL_TEXT.format("Locking Failed!")
+                    )
+                    click.echo(f"Output: {c.stdout.strip()}", err=True)
+                    click.echo(f"Error: {c.stderr.strip()}", err=True)
     if lockfile_section not in lockfile:
         lockfile[lockfile_section] = {}
-    prepare_lockfile(results, pipfile, lockfile[lockfile_section])
+    return prepare_lockfile(results, pipfile, lockfile[lockfile_section])
 
 
 def resolve_deps(
@@ -1083,19 +1153,16 @@ def resolve_deps(
     """
     index_lookup = {}
     markers_lookup = {}
-    python_path = which("python", allow_global=allow_global)
     if not os.environ.get("PIP_SRC"):
         os.environ["PIP_SRC"] = project.virtualenv_src_location
-    backup_python_path = sys.executable
     results = []
     resolver = None
     if not deps:
         return results, resolver
     # First (proper) attempt:
-    req_dir = req_dir if req_dir else os.environ.get("req_dir", None)
     if not req_dir:
         req_dir = create_tracked_tempdir(prefix="pipenv-", suffix="-requirements")
-    with HackedPythonVersion(python_version=python, python_path=python_path):
+    with HackedPythonVersion(python_path=project.python(system=allow_global)):
         try:
             results, hashes, markers_lookup, resolver, skipped = actually_resolve_deps(
                 deps,
@@ -1114,8 +1181,7 @@ def resolve_deps(
     # Second (last-resort) attempt:
     if results is None:
         with HackedPythonVersion(
-            python_version=".".join([str(s) for s in sys.version_info[:3]]),
-            python_path=backup_python_path,
+            python_path=project.python(system=allow_global),
         ):
             try:
                 # Attempt to resolve again, with different Python version information,
