@@ -19,7 +19,7 @@ def test_pipenv_where(pipenv_instance_pypi):
 @pytest.mark.cli
 def test_pipenv_venv(pipenv_instance_pypi):
     with pipenv_instance_pypi() as p:
-        c = p.pipenv('--python python')
+        c = p.pipenv('install dataclasses-json')
         assert c.returncode == 0
         c = p.pipenv('--venv')
         assert c.returncode == 0
@@ -94,11 +94,15 @@ def test_pipenv_graph(pipenv_instance_pypi):
 
 @pytest.mark.cli
 def test_pipenv_graph_reverse(pipenv_instance_private_pypi):
+    from pipenv.cli import cli
+    from click.testing import CliRunner  # not thread safe but graph is a tricky test
+
     with pipenv_instance_private_pypi() as p:
         c = p.pipenv('install tablib==0.13.0')
         assert c.returncode == 0
-        c = p.pipenv('graph --reverse')
-        assert c.returncode == 0
+        cli_runner = CliRunner(mix_stderr=False)
+        c = cli_runner.invoke(cli, "graph --reverse")
+        assert c.exit_code == 0
         output = c.stdout
 
         requests_dependency = [
@@ -169,7 +173,7 @@ def test_pipenv_check_check_lockfile_categories(pipenv_instance_pypi, category):
 
 @pytest.mark.cli
 def test_pipenv_clean(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with open('setup.py', 'w') as f:
             f.write('from setuptools import setup; setup(name="empty")')
         c = p.pipenv('install -e .')
@@ -224,7 +228,7 @@ def test_man(pipenv_instance_pypi):
 def test_install_parse_error(pipenv_instance_private_pypi):
     with pipenv_instance_private_pypi() as p:
 
-        # Make sure unparseable packages don't wind up in the pipfile
+        # Make sure unparsable packages don't wind up in the pipfile
         # Escape $ for shell input
         with open(p.pipfile_path, 'w') as f:
             contents = """
@@ -238,6 +242,7 @@ def test_install_parse_error(pipenv_instance_private_pypi):
         assert 'u/\\/p@r$34b13+pkg' not in p.pipfile['packages']
 
 
+@pytest.mark.skip(reason="This test clears the cache that other tests may be using.")
 @pytest.mark.cli
 def test_pipenv_clear(pipenv_instance_pypi):
     with pipenv_instance_pypi() as p:
@@ -248,7 +253,7 @@ def test_pipenv_clear(pipenv_instance_pypi):
 
 @pytest.mark.outdated
 def test_pipenv_outdated_prerelease(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, "w") as f:
             contents = """
 [packages]
