@@ -22,11 +22,10 @@ def test_basic_install(pipenv_instance_private_pypi):
 @pytest.mark.basic
 @pytest.mark.install
 def test_mirror_install(pipenv_instance_pypi):
-    with temp_environ(), pipenv_instance_pypi(chdir=True) as p:
+    with temp_environ(), pipenv_instance_pypi() as p:
         mirror_url = "https://pypi.python.org/simple"
         assert "pypi.org" not in mirror_url
         # This should sufficiently demonstrate the mirror functionality
-        # since pypi.org is the default when PIPENV_TEST_INDEX is unset.
         c = p.pipenv(f"install dataclasses-json --pypi-mirror {mirror_url}")
         assert c.returncode == 0
         # Ensure the --pypi-mirror parameter hasn't altered the Pipfile or Pipfile.lock sources
@@ -43,9 +42,8 @@ def test_mirror_install(pipenv_instance_pypi):
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_bad_mirror_install(pipenv_instance_pypi):
-    with temp_environ(), pipenv_instance_pypi(chdir=True) as p:
+    with temp_environ(), pipenv_instance_pypi() as p:
         # This demonstrates that the mirror parameter is being used
-        os.environ.pop("PIPENV_TEST_INDEX", None)
         c = p.pipenv("install dataclasses-json --pypi-mirror https://pypi.example.org")
         assert c.returncode != 0
 
@@ -59,7 +57,7 @@ def test_basic_dev_install(pipenv_instance_pypi):
         assert "dataclasses-json" in p.pipfile["dev-packages"]
         assert "dataclasses-json" in p.lockfile["develop"]
 
-        c = p.pipenv("run python -c 'from dataclasses_json import dataclass_json'")
+        c = p.pipenv("""run python -c "from dataclasses_json import dataclass_json" """)
         assert c.returncode == 0
 
 
@@ -68,7 +66,7 @@ def test_basic_dev_install(pipenv_instance_pypi):
 @pytest.mark.install
 def test_install_without_dev(pipenv_instance_private_pypi):
     """Ensure that running `pipenv install` doesn't install dev packages"""
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         with open(p.pipfile_path, "w") as f:
             contents = """
 [packages]
@@ -90,6 +88,22 @@ tablib = "*"
         assert c.returncode == 0
 
 
+@pytest.mark.basic
+@pytest.mark.install
+def test_install_with_version_req_default_operator(pipenv_instance_private_pypi):
+    """Ensure that running `pipenv install` work when spec is package = "X.Y.Z". """
+    with pipenv_instance_private_pypi() as p:
+        with open(p.pipfile_path, "w") as f:
+            contents = """
+[packages]
+six = "1.12.0"
+            """.strip()
+            f.write(contents)
+        c = p.pipenv("install")
+        assert c.returncode == 0
+        assert "six" in p.pipfile["packages"]
+
+
 @pytest.mark.basic
 @pytest.mark.install
 def test_install_without_dev_section(pipenv_instance_pypi):
@@ -114,7 +128,7 @@ six = "*"
 @pytest.mark.extras
 @pytest.mark.install
 def test_extras_install(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         c = p.pipenv("install requests[socks]")
         assert c.returncode == 0
         assert "requests" in p.pipfile["packages"]
@@ -217,12 +231,12 @@ def test_bad_packages(pipenv_instance_private_pypi):
 @pytest.mark.requirements
 def test_requirements_to_pipfile(pipenv_instance_private_pypi):
 
-    with pipenv_instance_private_pypi(pipfile=False, chdir=True) as p:
+    with pipenv_instance_private_pypi(pipfile=False) as p:
 
         # Write a requirements file
         with open("requirements.txt", "w") as f:
             f.write(
-                f"-i {os.environ['PIPENV_TEST_INDEX']}\n"
+                f"-i {p.index_url}\n"
                 "requests[socks]==2.19.1\n"
             )
 
@@ -255,7 +269,7 @@ def test_skip_requirements_when_pipfile(pipenv_instance_private_pypi):
     1. We do `pipenv install [package]`
     2. A Pipfile already exists when we run `pipenv install`.
     """
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         with open("requirements.txt", "w") as f:
             f.write("requests==2.18.1\n")
         c = p.pipenv("install six")
@@ -287,7 +301,7 @@ def test_clean_on_empty_venv(pipenv_instance_pypi):
 def test_install_does_not_extrapolate_environ(pipenv_instance_pypi):
     """Ensure environment variables are not expanded in lock file.
     """
-    with temp_environ(), pipenv_instance_pypi(chdir=True) as p:
+    with temp_environ(), pipenv_instance_pypi() as p:
         os.environ["PYPI_URL"] = p.pypi
 
         with open(p.pipfile_path, "w") as f:
@@ -330,7 +344,7 @@ def test_editable_no_args(pipenv_instance_pypi):
 def test_install_venv_project_directory(pipenv_instance_pypi):
     """Test the project functionality during virtualenv creation.
     """
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with temp_environ(), TemporaryDirectory(
             prefix="pipenv-", suffix="temp_workon_home"
         ) as workon_home:
@@ -351,7 +365,7 @@ def test_install_venv_project_directory(pipenv_instance_pypi):
 @pytest.mark.deploy
 @pytest.mark.system
 def test_system_and_deploy_work(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         c = p.pipenv("install urllib3")
         assert c.returncode == 0
         c = p.pipenv("--rm")
@@ -361,14 +375,13 @@ def test_system_and_deploy_work(pipenv_instance_private_pypi):
         c = p.pipenv("install --system --deploy")
         assert c.returncode == 0
 
+
 @pytest.mark.basic
 @pytest.mark.install
 def test_install_creates_pipfile(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         if os.path.isfile(p.pipfile_path):
             os.unlink(p.pipfile_path)
-        if "PIPENV_PIPFILE" in os.environ:
-            del os.environ["PIPENV_PIPFILE"]
         assert not os.path.isfile(p.pipfile_path)
         c = p.pipenv("install")
         assert c.returncode == 0
@@ -379,10 +392,10 @@ def test_install_creates_pipfile(pipenv_instance_pypi):
 
 @pytest.mark.basic
 @pytest.mark.install
-def test_create_pipfile_requires_python_full_version(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
-        python_version = str(sys.version_info.major) + "." + str(sys.version_info.minor)
-        python_full_version = python_version + "." + str(sys.version_info.micro)
+def test_create_pipfile_requires_python_full_version(pipenv_instance_private_pypi):
+    with pipenv_instance_private_pypi(pipfile=False) as p:
+        python_version = f"{sys.version_info.major}.{sys.version_info.minor}"
+        python_full_version = f"{python_version}.{sys.version_info.micro}"
         c = p.pipenv(f"--python {python_full_version}")
         assert c.returncode == 0
         assert p.pipfile["requires"] == {
@@ -394,7 +407,7 @@ def test_create_pipfile_requires_python_full_version(pipenv_instance_pypi):
 @pytest.mark.basic
 @pytest.mark.install
 def test_install_non_exist_dep(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         c = p.pipenv("install dateutil")
         assert c.returncode
         assert "dateutil" not in p.pipfile["packages"]
@@ -403,7 +416,7 @@ def test_install_non_exist_dep(pipenv_instance_pypi):
 @pytest.mark.basic
 @pytest.mark.install
 def test_install_package_with_dots(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         c = p.pipenv("install backports.html")
         assert c.returncode == 0
         assert "backports.html" in p.pipfile["packages"]
@@ -412,21 +425,54 @@ def test_install_package_with_dots(pipenv_instance_private_pypi):
 @pytest.mark.basic
 @pytest.mark.install
 def test_rewrite_outline_table(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         with open(p.pipfile_path, 'w') as f:
             contents = """
 [[source]]
-url = "{0}"
+url = "{}"
 verify_ssl = false
 name = "testindex"
 
 [packages]
-six = {1}
+six = {}
 
 [packages.requests]
 version = "*"
 extras = ["socks"]
-            """.format(os.environ['PIPENV_TEST_INDEX'], "{version = \"*\"}").strip()
+            """.format(p.index_url, "{version = \"*\"}").strip()
+            f.write(contents)
+        c = p.pipenv("install colorama")
+        assert c.returncode == 0
+        with open(p.pipfile_path) as f:
+            contents = f.read()
+        assert "[packages.requests]" not in contents
+        assert 'six = {version = "*"}' in contents
+        assert 'requests = {version = "*"' in contents
+        assert 'colorama = "*"' in contents
+
+
+@pytest.mark.basic
+@pytest.mark.install
+def test_rewrite_outline_table_ooo(pipenv_instance_private_pypi):
+    with pipenv_instance_private_pypi() as p:
+        with open(p.pipfile_path, 'w') as f:
+            contents = """
+[[source]]
+url = "{}"
+verify_ssl = false
+name = "testindex"
+
+[packages]
+six = {}
+
+# Out-of-order
+[pipenv]
+allow_prereleases = false
+
+[packages.requests]
+version = "*"
+extras = ["socks"]
+            """.format(p.index_url, "{version = \"*\"}").strip()
             f.write(contents)
         c = p.pipenv("install colorama")
         assert c.returncode == 0
@@ -443,7 +489,7 @@ extras = ["socks"]
 def test_install_dev_use_default_constraints(pipenv_instance_private_pypi):
     # See https://github.com/pypa/pipenv/issues/4371
     # See https://github.com/pypa/pipenv/issues/2987
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
 
         c = p.pipenv("install requests==2.14.0")
         assert c.returncode == 0
@@ -470,10 +516,10 @@ def test_install_dev_use_default_constraints(pipenv_instance_private_pypi):
 @pytest.mark.needs_internet
 def test_install_does_not_exclude_packaging(pipenv_instance_pypi):
     """Ensure that running `pipenv install` doesn't exclude packaging when its required. """
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         c = p.pipenv("install dataclasses-json")
         assert c.returncode == 0
-        c = p.pipenv("run python -c 'from dataclasses_json import DataClassJsonMixin'")
+        c = p.pipenv("""run python -c "from dataclasses_json import DataClassJsonMixin" """)
         assert c.returncode == 0
 
 
@@ -481,7 +527,7 @@ def test_install_does_not_exclude_packaging(pipenv_instance_pypi):
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_install_will_supply_extra_pip_args(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         c = p.pipenv("""install dataclasses-json --extra-pip-args="--use-feature=truststore --proxy=test" """)
         assert c.returncode == 1
         assert "truststore feature" in c.stderr
@@ -492,7 +538,7 @@ def test_install_will_supply_extra_pip_args(pipenv_instance_pypi):
 @pytest.mark.needs_internet
 def test_install_tarball_is_actually_installed(pipenv_instance_pypi):
     """ Test case for Issue 5326"""
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, "w") as f:
             contents = """
 [[source]]
@@ -508,5 +554,5 @@ dataclasses-json = {file = "https://files.pythonhosted.org/packages/85/94/1b3021
         assert c.returncode == 0
         c = p.pipenv("sync")
         assert c.returncode == 0
-        c = p.pipenv("run python -c 'from dataclasses_json import dataclass_json'")
+        c = p.pipenv("""run python -c "from dataclasses_json import dataclass_json" """)
         assert c.returncode == 0
