@@ -10,11 +10,15 @@ from pipenv.utils.processes import subprocess_run
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_basic_vcs_install_with_env_var(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    from pipenv.cli import cli
+    from click.testing import CliRunner  # not thread safe but macos and linux will expand the env var otherwise
+
+    with pipenv_instance_pypi() as p:
         # edge case where normal package starts with VCS name shouldn't be flagged as vcs
         os.environ["GIT_HOST"] = "github.com"
-        c = p.pipenv("install git+https://${GIT_HOST}/benjaminp/six.git@1.11.0#egg=six gitdb2")
-        assert c.returncode == 0
+        cli_runner = CliRunner(mix_stderr=False)
+        c = cli_runner.invoke(cli, "install git+https://${GIT_HOST}/benjaminp/six.git@1.11.0#egg=six gitdb2")
+        assert c.exit_code == 0
         assert all(package in p.pipfile["packages"] for package in ["six", "gitdb2"])
         assert "git" in p.pipfile["packages"]["six"]
         assert p.lockfile["default"]["six"] == {
@@ -28,11 +32,11 @@ def test_basic_vcs_install_with_env_var(pipenv_instance_pypi):
 @pytest.mark.files
 @pytest.mark.needs_internet
 def test_urls_work(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         # the library this installs is "django-cms"
         url = "https://github.com/lidatong/dataclasses-json/archive/refs/tags/v0.5.7.zip"
         c = p.pipenv(
-            "install {0}".format(url)
+            f"install {url}"
         )
         assert c.returncode == 0
 
@@ -46,8 +50,8 @@ def test_urls_work(pipenv_instance_pypi):
 
 @pytest.mark.urls
 @pytest.mark.files
-def test_file_urls_work(pipenv_instance_pypi, pip_src_dir):
-    with pipenv_instance_pypi(chdir=True) as p:
+def test_file_urls_work(pipenv_instance_pypi):
+    with pipenv_instance_pypi() as p:
         whl = Path(__file__).parent.parent.joinpath(
             "pypi", "six", "six-1.11.0-py2.py3-none-any.whl"
         )
@@ -56,7 +60,7 @@ def test_file_urls_work(pipenv_instance_pypi, pip_src_dir):
         except OSError:
             whl = whl.absolute()
         wheel_url = whl.as_uri()
-        c = p.pipenv('install "{0}"'.format(wheel_url))
+        c = p.pipenv(f'install "{wheel_url}"')
         assert c.returncode == 0
         assert "six" in p.pipfile["packages"]
         assert "file" in p.pipfile["packages"]["six"]
@@ -72,7 +76,7 @@ def test_file_urls_work(pipenv_instance_pypi, pip_src_dir):
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_editable_vcs_install(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         c = p.pipenv(
             "install -e git+https://github.com/lidatong/dataclasses-json.git#egg=dataclasses-json"
         )
@@ -85,7 +89,7 @@ def test_editable_vcs_install(pipenv_instance_pypi):
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_install_editable_git_tag(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         c = p.pipenv(
             "install -e git+https://github.com/benjaminp/six.git@1.11.0#egg=six"
         )
@@ -132,8 +136,8 @@ six = "*"
 @pytest.mark.index
 @pytest.mark.install
 @pytest.mark.needs_internet
-def test_install_specifying_index_url(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi() as p:
+def test_install_specifying_index_url(pipenv_instance_pypi):
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, "w") as f:
             contents = """
 [[source]]
@@ -146,8 +150,6 @@ six = "*"
 
 [dev-packages]
 
-[pipenv]
-install_search_all_sources = true
             """.strip()
             f.write(contents)
         c = p.pipenv("install pipenv-test-private-package --index https://test.pypi.org/simple")
@@ -163,7 +165,7 @@ install_search_all_sources = true
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_install_local_vcs_not_in_lockfile(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         # six_path = os.path.join(p.path, "six")
         six_path = p._pipfile.get_fixture_path("git/six/").as_posix()
         c = subprocess_run(["git", "clone", six_path, "./six"])
@@ -180,7 +182,7 @@ def test_install_local_vcs_not_in_lockfile(pipenv_instance_pypi):
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_get_vcs_refs(pipenv_instance_private_pypi):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         c = p.pipenv(
             "install -e git+https://github.com/benjaminp/six.git@1.9.0#egg=six"
         )
@@ -192,7 +194,7 @@ def test_get_vcs_refs(pipenv_instance_private_pypi):
             == "5efb522b0647f7467248273ec1b893d06b984a59"
         )
         pipfile = Path(p.pipfile_path)
-        new_content = pipfile.read_text().replace(u"1.9.0", u"1.11.0")
+        new_content = pipfile.read_text().replace("1.9.0", "1.11.0")
         pipfile.write_text(new_content)
         c = p.pipenv("lock")
         assert c.returncode == 0
@@ -213,11 +215,11 @@ def test_vcs_entry_supersedes_non_vcs(pipenv_instance_pypi):
     in the lockfile -- due to not running pip install before locking and not locking
     the resolution graph of non-editable vcs dependencies.
     """
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         jinja2_uri = p._pipfile.get_fixture_path("git/jinja2").as_uri()
         with open(p.pipfile_path, "w") as f:
             f.write(
-                """
+                f"""
 [[source]]
 url = "https://pypi.org/simple"
 verify_ssl = true
@@ -225,8 +227,8 @@ name = "pypi"
 
 [packages]
 Flask = "*"
-Jinja2 = {{ref = "2.11.0", git = "{0}"}}
-            """.format(jinja2_uri).strip()
+Jinja2 = {{ref = "2.11.0", git = "{jinja2_uri}"}}
+            """.strip()
             )
         c = p.pipenv("install")
         assert c.returncode == 0
@@ -246,9 +248,9 @@ Jinja2 = {{ref = "2.11.0", git = "{0}"}}
 @pytest.mark.install
 @pytest.mark.needs_internet
 def test_vcs_can_use_markers(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         path = p._pipfile.get_fixture_path("git/six/.git")
-        p._pipfile.install("six", {"git": "{0}".format(path.as_uri()), "markers": "sys_platform == 'linux'"})
+        p._pipfile.install("six", {"git": f"{path.as_uri()}", "markers": "sys_platform == 'linux'"})
         assert "six" in p.pipfile["packages"]
         c = p.pipenv("install")
         assert c.returncode == 0
