@@ -1,7 +1,5 @@
 import os
-import tarfile
 
-from pathlib import Path
 
 import pytest
 
@@ -9,14 +7,13 @@ from pipenv.project import Project
 from pipenv.utils.shell import temp_environ
 from pipenv.vendor.plette import Pipfile
 from pipenv.vendor.requirementslib.fileutils import normalize_path
-from pipenv.vendor.pythonfinder.utils import is_in_path
 
 
 @pytest.mark.project
 @pytest.mark.sources
 @pytest.mark.environ
 def test_pipfile_envvar_expansion(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with temp_environ():
             with open(p.pipfile_path, 'w') as f:
                 f.write("""
@@ -39,11 +36,11 @@ pytz = "*"
 @pytest.mark.sources
 @pytest.mark.parametrize('lock_first', [True, False])
 def test_get_source(pipenv_instance_private_pypi, lock_first):
-    with pipenv_instance_private_pypi(chdir=True) as p:
+    with pipenv_instance_private_pypi() as p:
         with open(p.pipfile_path, 'w') as f:
-            contents = """
+            contents = f"""
 [[source]]
-url = "{0}"
+url = "{p.index_url}"
 verify_ssl = false
 name = "testindex"
 
@@ -57,7 +54,7 @@ pytz = "*"
 six = {{version = "*", index = "pypi"}}
 
 [dev-packages]
-            """.format(os.environ['PIPENV_TEST_INDEX']).strip()
+            """.strip()
             f.write(contents)
 
         if lock_first:
@@ -67,7 +64,7 @@ six = {{version = "*", index = "pypi"}}
         project = Project()
         sources = [
             ['pypi', 'https://pypi.org/simple'],
-            ['testindex', os.environ.get('PIPENV_TEST_INDEX')]
+            ['testindex', p.index_url]
         ]
         for src in sources:
             name, url = src
@@ -86,7 +83,7 @@ six = {{version = "*", index = "pypi"}}
 @pytest.mark.project
 @pytest.mark.parametrize('newlines', ['\n', '\r\n'])
 def test_maintain_file_line_endings(pipenv_instance_pypi, newlines):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         # Initial pipfile + lockfile generation
         c = p.pipenv('install pytz')
         assert c.returncode == 0
@@ -95,16 +92,12 @@ def test_maintain_file_line_endings(pipenv_instance_pypi, newlines):
         for fn in [p.pipfile_path, p.lockfile_path]:
             with open(fn) as f:
                 contents = f.read()
-                written_newlines = f.newlines
 
-            assert written_newlines == '\n', '{!r} != {!r} for {}'.format(
-                written_newlines, '\n', fn,
-            )
             # message because of  https://github.com/pytest-dev/pytest/issues/3443
             with open(fn, 'w', newline=newlines) as f:
                 f.write(contents)
 
-        # Run pipenv install to programatically rewrite
+        # Run pipenv install to programmatically rewrite
         c = p.pipenv('install chardet')
         assert c.returncode == 0
 
@@ -113,21 +106,18 @@ def test_maintain_file_line_endings(pipenv_instance_pypi, newlines):
             with open(fn) as f:
                 f.read()    # Consumes the content to detect newlines.
                 actual_newlines = f.newlines
-            assert actual_newlines == newlines, '{!r} != {!r} for {}'.format(
-                actual_newlines, newlines, fn,
-            )
-            # message because of  https://github.com/pytest-dev/pytest/issues/3443
+            assert actual_newlines == newlines, f'{actual_newlines!r} != {newlines!r} for {fn}'
 
 
 @pytest.mark.project
 @pytest.mark.sources
 @pytest.mark.needs_internet
 def test_many_indexes(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, 'w') as f:
-            contents = """
+            contents = f"""
 [[source]]
-url = "{0}"
+url = "{p.index_url}"
 verify_ssl = false
 name = "testindex"
 
@@ -146,44 +136,16 @@ pytz = "*"
 six = {{version = "*", index = "pypi"}}
 
 [dev-packages]
-            """.format(os.environ['PIPENV_TEST_INDEX']).strip()
+            """.strip()
             f.write(contents)
         c = p.pipenv('install')
         assert c.returncode == 0
 
 
-@pytest.mark.project
-@pytest.mark.virtualenv
-def test_run_in_virtualenv_with_global_context(pipenv_instance_pypi, virtualenv):
-    with pipenv_instance_pypi(chdir=True, venv_root=virtualenv.as_posix(), ignore_virtualenvs=False, venv_in_project=False) as p:
-        c = p.pipenv("run pip freeze")
-        assert c.returncode == 0, (c.stdout, c.stderr)
-        assert 'Creating a virtualenv' not in c.stderr, c.stderr
-        project = Project()
-        assert Path(project.virtualenv_location).resolve() == Path(virtualenv), (
-            project.virtualenv_location, str(virtualenv)
-        )
-
-        c = p.pipenv(f"run pip install -i {p.index_url} click")
-        assert c.returncode == 0, (c.stdout, c.stderr)
-        assert "Courtesy Notice" in c.stderr, (c.stdout, c.stderr)
-
-        c = p.pipenv("install six")
-        assert c.returncode == 0, (c.stdout, c.stderr)
-
-        c = p.pipenv("run python -c 'import click;print(click.__file__)'")
-        assert c.returncode == 0, (c.stdout, c.stderr)
-        assert is_in_path(c.stdout.strip(), str(virtualenv)), (c.stdout.strip(), str(virtualenv))
-
-        c = p.pipenv("clean --dry-run")
-        assert c.returncode == 0, (c.stdout, c.stderr)
-        assert "click" in c.stdout, c.stdout
-
-
 @pytest.mark.project
 @pytest.mark.virtualenv
 def test_run_in_virtualenv(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         c = p.pipenv('run pip freeze')
         assert c.returncode == 0
         assert 'Creating a virtualenv' in c.stderr
@@ -205,7 +167,7 @@ def test_run_in_virtualenv(pipenv_instance_pypi):
 @pytest.mark.project
 @pytest.mark.sources
 def test_no_sources_in_pipfile(pipenv_instance_pypi):
-    with pipenv_instance_pypi(chdir=True) as p:
+    with pipenv_instance_pypi() as p:
         with open(p.pipfile_path, 'w') as f:
             contents = """
 [packages]
